# generated by datamodel-codegen:
#   filename:  data/policy/DataConsumerPolicy.json
#   timestamp: 2022-05-10T08:41:27+00:00

from __future__ import annotations

from typing import Any

from pydantic import BaseModel, Field


class Model(BaseModel):
    __root__: Any = Field(
        ...,
        description='Policy for Data Consumer to perform operations on metadata entities',
    )
