# generated by datamodel-codegen:
#   filename:  schema/tests/table/tableRowCountToBeBetween.json
#   timestamp: 2022-05-10T08:41:27+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field


class TableRowCountToBeBetween(BaseModel):
    class Config:
        extra = Extra.forbid

    minValue: Optional[int] = Field(
        None,
        description='Expected number of rows should be greater than or equal to {minValue}. If minValue is not included, maxValue is treated as upperBound and there will be no minimum number of rows',
    )
    maxValue: Optional[int] = Field(
        None,
        description='Expected number of rows should be lower than or equal to {maxValue}. if maxValue is not included, minValue is treated as lowerBound and there will eb no maximum number of rows',
    )
