# generated by datamodel-codegen:
#   filename:  schema/api/services/createDatabaseService.json
#   timestamp: 2022-05-10T08:41:27+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field

from ...entity.services import databaseService
from ...type import basic, entityReference


class CreateDatabaseServiceRequest(BaseModel):
    class Config:
        extra = Extra.forbid

    name: basic.EntityName = Field(
        ..., description='Name that identifies the this entity instance uniquely'
    )
    description: Optional[str] = Field(
        None, description='Description of Database entity.'
    )
    serviceType: databaseService.DatabaseServiceType
    connection: databaseService.DatabaseConnection
    owner: Optional[entityReference.EntityReference] = Field(
        None, description='Owner of this database service.'
    )
