# generated by datamodel-codegen:
#   filename:  schema/entity/services/connections/database/deltaLakeConnection.json
#   timestamp: 2022-05-10T08:41:27+00:00

from __future__ import annotations

from enum import Enum
from typing import Optional

from pydantic import BaseModel, Extra, Field

from .. import connectionBasicType


class DeltaLakeType(Enum):
    DeltaLake = 'DeltaLake'


class DeltaLakeConnection(BaseModel):
    class Config:
        extra = Extra.forbid

    type: Optional[DeltaLakeType] = Field(
        'DeltaLake', description='Service Type', title='Service Type'
    )
    metastoreHostPort: Optional[str] = Field(
        None,
        description='Host and port of the remote Hive Metastore.',
        title='Metastore Host and Port',
    )
    metastoreFilePath: Optional[str] = Field(
        None,
        description='File path of the local Hive Metastore.',
        title='Metastore Local File Path',
    )
    appName: Optional[str] = Field(
        None, description='pySpark App Name.', title='Application Name'
    )
    connectionOptions: Optional[connectionBasicType.ConnectionOptions] = Field(
        None, title='Connection Options'
    )
    connectionArguments: Optional[connectionBasicType.ConnectionArguments] = Field(
        None, title='Connection Arguments'
    )
    supportsMetadataExtraction: Optional[
        connectionBasicType.SupportsMetadataExtraction
    ] = Field(None, title='Supports Metadata Extraction')
    supportsProfiler: Optional[connectionBasicType.SupportsProfiler] = Field(
        None, title='Supports Profiler'
    )
