# generated by datamodel-codegen:
#   filename:  schema/entity/teams/authN/ssoAuth.json
#   timestamp: 2022-05-10T08:41:27+00:00

from __future__ import annotations

from enum import Enum
from typing import Optional

from pydantic import BaseModel, Extra, Field


class SsoServiceType(Enum):
    Google = 'Google'
    Okta = 'Okta'
    CustomOIDC = 'CustomOIDC'
    Auth0 = 'Auth0'
    Azure = 'Azure'


class SSOAuthMechanism(BaseModel):
    class Config:
        extra = Extra.forbid

    ssoServiceType: Optional[SsoServiceType] = Field(
        None, description='Type of database service such as Amundsen, Atlas...'
    )
