# generated by datamodel-codegen:
#   filename:  schema/metadataIngestion/databaseServiceProfilerPipeline.json
#   timestamp: 2022-05-10T08:41:27+00:00

from __future__ import annotations

from enum import Enum
from typing import Optional

from pydantic import BaseModel, Extra, Field

from ..type import filterPattern


class ProfilerConfigType(Enum):
    Profiler = 'Profiler'


class DatabaseServiceProfilerPipeline(BaseModel):
    class Config:
        extra = Extra.forbid

    type: Optional[ProfilerConfigType] = Field('Profiler', description='Pipeline type')
    fqnFilterPattern: Optional[filterPattern.FilterPattern] = Field(
        None, description='Regex to only fetch tables with FQN matching the pattern.'
    )
