# generated by datamodel-codegen:
#   filename:  schema/api/createBot.json
#   timestamp: 2022-05-10T08:41:27+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field

from ..type import basic, entityReference


class CreateBot(BaseModel):
    class Config:
        extra = Extra.forbid

    name: basic.EntityName = Field(..., description='Name of the bot.')
    displayName: Optional[str] = Field(
        None,
        description="Name used for display purposes. Example 'FirstName LastName'.",
    )
    botUser: entityReference.EntityReference = Field(
        ...,
        description='Bot user created for this bot on behalf of which the bot performs all the operations, such as updating description, responding on the conversation threads, etc.',
    )
    description: Optional[str] = Field(None, description='Description of the bot.')
